R framework to facilitate fisheries data reporting flows, with first intention to help countries to validate, format and send data to relevant organizations including regional fisheries management organizations or bodies handling #' data collection reference frameworks, and FAO.
Author
Emmanuel Blondel emmanuel.blondel1@gmail.com